@@ -96,3 +96,31 @@ class ATR_StopLossFinder(Indicator):
                          SecondLevel="")
         self.Value_1 = Value_1
         self.Value_2 = Value_2
+
+@dataclass
+class Sell_Buy_Rates(Indicator):
+    Value_1: float
+    Value_2: float
+
+    def __init__(self, Value_1: float = 0, Value_2: float = 0, ):
+        super().__init__(Id="PUB;LzjHUC8QDN1HzufYCSLfxaV4b9yR6TMx",
+                         Name="Sell_Buy_Rates",
+                         Script="Script@tv-scripting-101!",
+                         FirstLevel="",
+                         SecondLevel="")
+        self.Value_1 = Value_1
+        self.Value_2 = Value_2
+
+@dataclass
+class CM_Williams_Vix_Fix(Indicator):
+    Value_1: float
+    Value_2: float
+
+    def __init__(self, Value_1: float = 0, Value_2: float = 0, ):
+        super().__init__(Id="PUB;239",
+                         Name="CM_Williams_Vix_Fix",
+                         Script="Script@tv-scripting-101!",
+                         FirstLevel="",
+                         SecondLevel="")
+        self.Value_1 = Value_1
+        self.Value_2 = Value_2
\ No newline at end of file
